@@ -93,7 +93,8 @@ class mysqlUtil:
             ftype = ".mp4"
             'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
                 ftype)
-        df = pd.read_sql(sql, self.engine)
+        connection = self.engine.connect()
+        df = pd.read_sql(sql, con=connection)
         results = json.loads(df.to_json(orient='records'))
         if results and len(results) == 1:
             return results[0]
@@ -112,7 +113,8 @@ class mysqlUtil:
             pid = "p023101".lower()
             'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
-        df = pd.read_sql(sql, self.engine)
+        connection = self.engine.connect()
+        df = pd.read_sql(sql,  con=connection)
         results = json.loads(df.to_json(orient='records'))
         if results and len(results) == 1:
             return results[0]
